
library(ggplot2)
library(readxl)
library(Rmisc)
library(reshape2)
library(mgcv)
library(investr)
library(raster)
library(rgdal)
library(rgeos)
library("rnaturalearth")
library(maptools)
library(cowplot)
library(ggspatial)
library(ggrepel)
library(sf)
library(MASS)
library(plyr)
library(ggplot2)
library(dplyr)
library(tidyr)
library(patchwork)

isodata <- read_excel("C:/Users/vr371/Dropbox/Papers/Great hammer and ACR/GHH biogeography/Biogeography isotope data updated test Tassie squid adjusted.xlsx")

#model fit: GAM WITH LIPID ADJUSTMENT - 13C VALUES < -18

gamfit <- gam((adj13Ctest-1.5) ~ s(Lat, k = 5), data = isodata[which(isodata$Species != "S. mokarran" & isodata$adj13Ctest < -18),], method = "REML")
mean(abs(residuals.gam(gamfit)))


#Create prediction DF

newdat <- data.frame(Lat = seq(-45, -10, by = 1))
sharkdat <- isodata[which(isodata$Species == "S. mokarran" & isodata$Tissue == "Muscle"),]
sharkdat <- as.data.frame(sharkdat)
sharkdat$ID <- seq(1:27)


#GAM MODEL WITH LIPID ADJUSTMENT DATA

predictgamfit <- predict(gamfit, newdat, se.fit = TRUE)
predictgamfit <- as.data.frame(predictgamfit)
predictgamfit$Lat <- newdat$Lat
predictgamfit$Lat <- as.numeric(predictgamfit$Lat)



#turn GHHpredict into CSV

#adjust limits of prediction from SE for GAM

predictgamfit$lwr <- (predictgamfit$fit - 1.645*predictgamfit$se.fit)
predictgamfit$upr <- (predictgamfit$fit +  1.645*predictgamfit$se.fit)

write.csv(predictgamfit, "Ground-truthed model.csv")

jitter <- position_jitter(width = 0.1, height = 0.1)


#model plot


fitgamplot <- ggplot(data = predictgamfit, aes(x = Lat , fit, lwr, upr, group = 1)) + 
  geom_line(aes(y = fit), size = 1) +
  geom_line(aes(y = lwr), linetype = "dashed") + geom_line(aes(y = upr), linetype = "dashed") + 
  geom_ribbon(aes(ymin = lwr, ymax = upr), alpha = 0.2)  + theme_classic() + 
  xlab("Latitude") + ylab(expression(paste(delta^13, "C (\u2030)",sep=""))) + 
  geom_point(data = isodata[which(isodata$Species == "S. mokarran"),], aes( x = Lat, y = adj13Ctest-1.5), position = jitter, shape = "triangle", size = 2) + 
  geom_point(data = isodata[which(isodata$Species != "S. mokarran" & isodata$adj13Ctest < -18),], aes(x = Lat, y = adj13Ctest-1.5, colour = Species), position = jitter, shape = "circle", alpha = 0.5) + 
  theme(legend.position = "none") + scale_y_continuous(limits = c(-30, -15)) + scale_x_continuous(limits = c(-45, -20)) + scale_colour_grey()

fitgamplot


#MEDUsA modelling

medusa <- read.csv("Raw data annual C.csv")

medusagamfit <- gam(layer ~ s(Lat, k = 5), data = medusa)

newdat <- data.frame(Lat = c(-45: -10))
predictmedusagamfit <- predict(medusagamfit, newdat, se.fit = TRUE)
predictmedusagamfit <- as.data.frame(predictmedusagamfit)
predictmedusagamfit$Lat <- newdat$Lat
mean(abs(residuals.gam(medusagamfit)))


predictmedusagamfit$lwr <- (predictmedusagamfit$fit - mean(abs(residuals.gam(medusagamfit))))
predictmedusagamfit$upr <- (predictmedusagamfit$fit + mean(abs(residuals.gam(medusagamfit))))

fitmedusagamplot <- ggplot(data = predictmedusagamfit, aes(x = Lat , fit, lwr, upr, group = 1)) + 
  geom_line(aes(y = fit), size = 1) +
  geom_line(aes(y = lwr), linetype = "dashed") + geom_line(aes(y = upr), linetype = "dashed") + 
  geom_ribbon(aes(ymin = lwr, ymax = upr), alpha = 0.2)  + theme_classic() + 
  xlab("Latitude") + ylab(expression(paste(delta^13, "C (\u2030)",sep=""))) + 
  geom_point(data = medusa, aes(x = Lat, y = layer), position = jitter, shape = "circle", alpha = 0.5, colour = "grey") + theme(legend.position = "none") + ylim(-30, -15) + 
  xlim(-45, -20) +  geom_point(data = isodata[which(isodata$Species == "S. mokarran"),], aes( x = Lat, y = adj13Ctest-1.5), position = jitter,fill = "black", size = 2, shape = "triangle")

fitmedusagamplot

#combine both latitudinal models

fitgamplot + fitmedusagamplot

#difference between models

moddiff <- data.frame(predictmedusagamfit$Lat, predictmedusagamfit$fit, predictgamfit$fit)
moddiff$diff <- abs(moddiff$predictmedusagamfit.fit - moddiff$predictgamfit.fit)

diffplot <- ggplot(data = moddiff, aes(x = predictmedusagamfit.Lat, y = diff)) + geom_line() + theme_classic() + ylab("Difference in predicted stable isotope value") + xlab("Latitude") + scale_x_continuous(limits = c(-45, -20))
diffplot

#determine shark values that are within each CI


# Read in parameters and assign names

GHHparams <- read_excel("GHHparams.xlsx")

for (i in 1:length(GHHparams$Parameter))
{
  nam <- paste("GHH_ndist_", GHHparams$Parameter[i], sep="") # create the variable name
  assign(nam, rnorm(1000, GHHparams$Mean[i], GHHparams$SD[i])) # assign the result of the function to the variable named with the name
  nam1 <- paste("GHH_mean_",GHHparams$Parameter[i], sep="") # create the variable name
  assign(nam1, GHHparams$Mean[i]) # assign the result of the function to the variable named with the name
  nam2 <- paste("GHH_90CI_",GHHparams$Parameter[i], sep="") # create the variable name
  assign(nam2, GHHparams$Mean[i] + 1.645*GHHparams$SD[i]) # assign the result of the function to the variable named with the name
}



## RUN MAJOR MODEL LOOP
nruns <- 10000 # how many runs to do
GHH_output <- data.frame(run = numeric(nruns), lipidadj13C = numeric(nruns), d15N = numeric(nruns), rn_dN = numeric(nruns), rn_dC = numeric(nruns), Bayesian13C = numeric(nruns))

#loop for selecting random shark SIA values

for (i in 1:nruns){
rn_SIA_Dat <- sharkdat[sample(nrow(sharkdat), 1),]
  d15N <- rn_SIA_Dat$d15N
  lipadj13C  <- rn_SIA_Dat$lipadj13C -1.5
  }


#adjustment loop

for (i in 1:nruns){
  rn_SIA_Dat <- sharkdat[sample(nrow(sharkdat), 1),]
  d15N <- rn_SIA_Dat$d15N
  lipadj13C  <- rn_SIA_Dat$lipadj13C
  rn_dN <- sample(GHH_ndist_dN,1)
  rn_dC <- sample(GHH_ndist_dC,1)

  Bayesian13C <- (lipadj13C - ((d15N - 6.5)/rn_dN)*rn_dC)
    
  sim_res <- c(i, lipadj13C, d15N, rn_dC, rn_dN, Bayesian13C)
  
  GHH_output[i,] <- sim_res
  
}

write.table(GHH_output, "Sharkinversepreds.csv", sep = ",")
GHH_output$count <- 1
GHH_output$Bayesian13C <- GHH_output$Bayesian13C - 1.5

#Predict number of sharks that fit into CIs of GAM for each degree of latitude


predictgamfit$sharkcount <- mapply(function(lwr, upr) with(GHH_output, sum(count[Bayesian13C > lwr & Bayesian13C < upr])),
                                   predictgamfit$lwr,predictgamfit$upr)


predictgamfit$sharkprop <- predictgamfit$sharkcount / sum(predictgamfit$sharkcount)



#Density plot and map (have to do MEDUSA data analyses first!!!!)#############################################################

Medusasharkprop <- read_excel("Medusasharkprop.xlsx")

Density <-  ggplot(data = predictgamfit, aes(x = Lat)) + geom_area(aes(y = sharkprop), alpha = 0.5, colour = "black", fill = "#481567FF") + 
  geom_area(data = Medusasharkprop, aes(y = Sharkprop, x = Lat), alpha = 0.5, colour = "black", fill = "#FDE725FF") + 
  theme_classic() + ylab("Proportion modelled population") + xlab("Latitude") + scale_fill_viridis_d(alpha = c(0.25, 0.5, 0.25)) + 
  scale_y_reverse() + coord_flip() + scale_x_continuous(position = "top", limits = c(-45, -15), expand= c(0, 0))

Cities <- read_excel("Cities.xlsx")
oz_shape <- rnaturalearth::ne_states(geounit = "australia")
oz_shape <- map_data(oz_shape)
oz_shape <- fortify(oz_shape)
idlist <- oz_shape$region
oz <- ne_states(returnclass = "sf")


map <- ggplot(data = oz) + geom_sf()  +
  coord_sf(xlim = c(145, 160), ylim = c(-45, -15), expand = FALSE) + theme_classic() + annotation_scale(location = "bl", width_hint = 1) +
  geom_point(data = Cities, aes(x = Long, y = Lat)) +   geom_text_repel(data = Cities, aes(x = Long, y = Lat, label = City), 
  fontface = "bold", nudge_x = c(2, 2, 2, 2, 2, 2), nudge_y = c(-1,1,-1,-1,2,1)) + ylab("Latitude") + xlab("Longitude") + scale_x_continuous(breaks = c(150, 155, 160))
plot_grid(map, Density)


#C MEDUSA plot
clayer <- raster("AnnualC.gri")
clayerdata <- as.data.frame(clayer, xy =TRUE)
mapC <- ggplot(data = oz)  + geom_raster(data = clayerdata, aes(x = x, y = y, fill = layer)) + geom_sf() +
  coord_sf(xlim = c(145, 165), ylim = c(-45, -10), expand = FALSE) + theme_classic() + annotation_scale(location = "br", width_hint = 1) +
  geom_point(data = Cities, aes(x = Long, y = Lat)) +   geom_text_repel(data = Cities, aes(x = Long, y = Lat, label = City), 
  fontface = "bold", nudge_x = c(2, 2, 2, 2, 2, 2), nudge_y = c(-1,1,-1,-1,1,1)) + ylab("Latitude") + xlab("Longitude") + scale_x_continuous(breaks = c(150, 155, 160)) +
   scale_fill_viridis_c(na.value = "white", name = expression(paste(delta^13, "C (\u2030)",sep=""))) 



#use MCMC data to determine habitat with mean residual from GAM

clayer <- raster("AnnualC.gri")
clayerdata <- as.data.frame(clayer, xy =TRUE)
clayerdata$lwr <- (clayerdata$layer - mean(abs(residuals.gam(medusagamfit))))
clayerdata$upr <- (clayerdata$layer + mean(abs(residuals.gam(medusagamfit))))     

clayerdata$sharkcount <- mapply(function(lwr, upr) with(GHH_output, sum(count[Bayesian13C > lwr & Bayesian13C < upr])),
                                   clayerdata$lwr,clayerdata$upr)


clayerdata$sharkprop <- clayerdata$sharkcount / sum(clayerdata$sharkcount, na.rm = TRUE)






#GRAPH

medusapopmap <- ggplot(data = oz)  + geom_raster(data = clayerdata, aes(x = x, y = y, fill = sharkprop)) + geom_sf() +
  coord_sf(xlim = c(145, 165), ylim = c(-45, -10), expand = FALSE) + theme_classic() + annotation_scale(location = "br", width_hint = 1) +
  geom_point(data = Cities, aes(x = Long, y = Lat)) +   geom_text_repel(data = Cities, aes(x = Long, y = Lat, label = City), 
                                                                        fontface = "bold", nudge_x = c(2, 2, 2, 2, 2, 2), nudge_y = c(-1,1,-1,-1,1,1)) + ylab("Latitude") + xlab("Longitude") + scale_x_continuous(breaks = c(150, 155, 160)) +
  scale_fill_viridis_c(na.value = "white", name = "Proportion modelled population")

medusapopmap


#model verification with sawsharks (same approach as GHH)

sawshark <- read_excel("sawshark dat.xlsx")
sawshark_params <- read.csv("sawshark params.csv")

for (i in 1:length(sawshark_params$Parameter))
{
  nam <- paste("saw_ndist_", sawshark_params$Parameter[i], sep="") # create the variable name
  assign(nam, rnorm(1000, sawshark_params$Mean[i], sawshark_params$SD[i])) # assign the result of the function to the variable named with the name
  nam1 <- paste("saw_mean_",sawshark_params$Parameter[i], sep="") # create the variable name
  assign(nam1, sawshark_params$Mean[i]) # assign the result of the function to the variable named with the name
  nam2 <- paste("saw_90CI_",sawshark_params$Parameter[i], sep="") # create the variable name
  assign(nam2, sawshark_params$Mean[i] + 1.645*sawshark_params$SD[i]) # assign the result of the function to the variable named with the name
}



## RUN MAJOR MODEL LOOP
nruns <- 10000 # how many runs to do
Saw_output <- data.frame(run = numeric(nruns), d13C = numeric(nruns), d15N = numeric(nruns), rn_U = numeric(nruns), rn_dN = numeric(nruns), rn_dC = numeric(nruns), Bayesian13C = numeric(nruns))

#loop for selecting random shark SIA values

for (i in 1:nruns){
  rn_SIA_Dat <- sawshark[sample(nrow(sawshark), 1),]
  d15N <- rn_SIA_Dat$d15N
  d13C  <- rn_SIA_Dat$d13C
}


#adjustment loop

for (i in 1:nruns){
  rn_SIA_Dat <- sawshark[sample(nrow(sawshark), 1),]
  d15N <- rn_SIA_Dat$d15N
  d13C  <- rn_SIA_Dat$d13C
  rn_dN <- sample(saw_ndist_dN,1)
  rn_dC <- sample(saw_ndist_dC,1)
  rn_U <- sample(saw_ndist_U,1)
  
  Bayesian13C <- (d13C - (((d15N + rn_U) - 6.5)/rn_dN)*rn_dC)
  
  sim_res <- c(i, d13C, d15N, rn_dC, rn_dN, rn_U, Bayesian13C)
  
  Saw_output[i,] <- sim_res
  
}

write.table(Saw_output, "SawSharkinversepreds.csv", sep = ",")
Saw_output$count <- 1
Saw_output$Bayesian13C <- Saw_output$Bayesian13C - 1.5

predictgamfit$sharkcount <- mapply(function(lwr, upr) with(Saw_output, sum(count[Bayesian13C > lwr & Bayesian13C < upr])),
                                   predictgamfit$lwr,predictgamfit$upr)


predictgamfit$sharkprop <- predictgamfit$sharkcount / sum(predictgamfit$sharkcount)

#ground-truthed data

#combine longitudinal pop data from MEDUSA into latitudes

sawsharkmedusaprop <- read_excel("sawsharkmedusaprop.xlsx")

Density <-  ggplot(data = predictgamfit, aes(x = Lat)) + geom_area(aes(y = sharkprop), alpha = 0.5, colour = "black", fill = "#481567FF") +
  theme_classic()  + geom_area(data = sawsharkmedusaprop, aes(y = Sharkprop, x = Lat), alpha = 0.5, colour = "black", fill = "#FDE725FF") +
  ylab("Proportion modelled population") + xlab("Latitude") + scale_fill_viridis_d(alpha = c(0.25, 0.5, 0.25)) + 
  scale_y_reverse() + coord_flip() + scale_x_continuous(position = "top", limits = c(-45, -15), expand= c(0, 0))

Cities <- read_excel("Cities.xlsx")
oz_shape <- rnaturalearth::ne_states(geounit = "australia")
oz_shape <- map_data(oz_shape)
oz_shape <- fortify(oz_shape)
idlist <- oz_shape$region
oz <- ne_states(returnclass = "sf")


map <- ggplot(data = oz) + geom_sf()  +
  coord_sf(xlim = c(145, 160), ylim = c(-45, -15), expand = FALSE) + theme_classic() + annotation_scale(location = "bl", width_hint = 1) +
  geom_point(data = Cities, aes(x = Long, y = Lat)) +   geom_text_repel(data = Cities, aes(x = Long, y = Lat, label = City), 
                                                                        fontface = "bold", nudge_x = c(2, 2, 2, 2, 2, 2), nudge_y = c(-1,1,-1,-1,2,1)) + ylab("Latitude") + xlab("Longitude") + scale_x_continuous(breaks = c(150, 155, 160))
map + Density


#medusa

clayer <- raster("AnnualC.gri")
clayerdata <- as.data.frame(clayer, xy =TRUE)
clayerdata$lwr <- (clayerdata$layer - mean(abs(residuals.gam(medusagamfit))))
clayerdata$upr <- (clayerdata$layer + mean(abs(residuals.gam(medusagamfit))))     

clayerdata$sharkcount <- mapply(function(lwr, upr) with(Saw_output, sum(count[Bayesian13C > lwr & Bayesian13C < upr])),
                                clayerdata$lwr,clayerdata$upr)


clayerdata$sharkprop <- clayerdata$sharkcount / sum(clayerdata$sharkcount, na.rm = TRUE)


medusapopmap <- ggplot(data = oz)  + geom_raster(data = clayerdata, aes(x = x, y = y, fill = sharkprop)) + geom_sf() +
  coord_sf(xlim = c(145, 165), ylim = c(-45, -10), expand = FALSE) + theme_classic() + annotation_scale(location = "br", width_hint = 1) +
  geom_point(data = Cities, aes(x = Long, y = Lat)) +   geom_text_repel(data = Cities, aes(x = Long, y = Lat, label = City), 
                                                                        fontface = "bold", nudge_x = c(2, 2, 2, 2, 2, 2), nudge_y = c(-1,1,-1,-1,1,1)) + ylab("Latitude") + xlab("Longitude") + scale_x_continuous(breaks = c(150, 155, 160)) +
  scale_fill_viridis_c(na.value = "white", name = "Proportion modelled population")

medusapopmap

